"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.zoneCreator = void 0;
const alwayscli_1 = require("@alwaysai/alwayscli");
const cli_inputs_1 = require("../cli-inputs");
const docker_1 = require("../components/docker");
const user_1 = require("../components/user");
const util_1 = require("../util");
const docker_2 = require("../util/docker");
const logSymbols = require("log-symbols");
const chalk = require("chalk");
const website_prompt_1 = require("../util/website-prompt");
const zoneCreatorFunc = () => (0, alwayscli_1.CliLeaf)({
    name: 'zone-creator',
    description: 'Run zone creation tool',
    namedInputs: {
        yes: cli_inputs_1.yesCliInput
    },
    async action(_, { yes }) {
        await (0, user_1.checkUserIsLoggedInComponent)({ yes });
        await (0, docker_1.checkForDockerComponent)();
        const spawner = (0, util_1.JsSpawner)();
        const zoneDockerImageId = 'alwaysai/zone-creator';
        const zoneTutorial = 'https://alwaysai.co/tutorials/how-to-use-alwaysais-new-zone-editor-tool';
        const log = `${logSymbols.warning} The Zone Creator CLI tool will be deprecated in a future release.\nPlease use the new Zone Tool on the alwaysAI Console!\nRead how here: ${chalk.bold(zoneTutorial)}`;
        (0, util_1.echo)(log);
        await (0, website_prompt_1.websitePrompt)(zoneTutorial);
        await (0, docker_2.runDockerContainerForeground)({
            targetHostSpawner: spawner,
            cmd: {
                dockerImageId: zoneDockerImageId,
                remove: true,
                ports: ['5000'],
                pullImage: true
            }
        });
    }
});
exports.zoneCreator = zoneCreatorFunc();
//# sourceMappingURL=zone-creator.js.map